@@ -39,20 +39,11 @@
 
 G_DEFINE_TYPE (ChamplainLayer, champlain_layer, CLUTTER_TYPE_GROUP)
 
-#define GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHAMPLAIN_TYPE_LAYER, ChamplainLayerPrivate))
-
 enum
 {
   PROP_0
 };
 
-typedef struct _ChamplainLayerPrivate ChamplainLayerPrivate;
-
-struct _ChamplainLayerPrivate {
-  gpointer spacer;
-};
-
 static void layer_add_cb (ClutterGroup *layer,
     ClutterActor *marker,
     gpointer data);
@@ -63,7 +54,7 @@ static void layer_remove_cb (ClutterGroup *layer,
 static void
 champlain_layer_get_property (GObject *object,
     guint property_id,
-    GValue *value,
+    G_GNUC_UNUSED GValue *value,
     GParamSpec *pspec)
 {
   //ChamplainLayer *self = CHAMPLAIN_LAYER (object);
@@ -77,7 +68,7 @@ champlain_layer_get_property (GObject *object,
 static void
 champlain_layer_set_property (GObject *object,
     guint property_id,
-    const GValue *value,
+    G_GNUC_UNUSED const GValue *value,
     GParamSpec *pspec)
 {
   //ChamplainLayer *self = CHAMPLAIN_LAYER (object);
@@ -88,13 +79,25 @@ champlain_layer_set_property (GObject *object,
     }
 }
 
+static void
+champlain_layer_dispose (GObject *object)
+{
+  G_OBJECT_CLASS (champlain_layer_parent_class)->dispose (object);
+}
+
+static void
+champlain_layer_finalize (GObject *object)
+{
+  G_OBJECT_CLASS (champlain_layer_parent_class)->finalize (object);
+}
+
 static void
 champlain_layer_class_init (ChamplainLayerClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (ChamplainLayerPrivate));
-
+  object_class->finalize = champlain_layer_finalize;
+  object_class->dispose = champlain_layer_dispose;
   object_class->get_property = champlain_layer_get_property;
   object_class->set_property = champlain_layer_set_property;
 }
@@ -117,8 +120,7 @@ static void
 reorder_marker (ClutterGroup *layer,
     ChamplainBaseMarker *marker)
 {
-  GList* markers = clutter_container_get_children (CLUTTER_CONTAINER(layer));
-  GList* it;
+  guint i;
   gdouble y, tmp_y, low_y;
   ChamplainBaseMarker *lowest = NULL;
 
@@ -126,9 +128,9 @@ reorder_marker (ClutterGroup *layer,
   y = 90 - y;
   low_y = G_MAXDOUBLE;
 
-  for (it = markers; it != NULL; it = it->next)
+  for (i = 0; i < clutter_group_get_n_children (layer); i++)
     {
-      ChamplainBaseMarker *prev_marker = (ChamplainBaseMarker*) it->data;
+      ChamplainBaseMarker *prev_marker = CHAMPLAIN_BASE_MARKER (clutter_group_get_nth_child (layer, i));
 
       if (prev_marker == (ChamplainBaseMarker*) marker)
         continue;
@@ -146,13 +148,11 @@ reorder_marker (ClutterGroup *layer,
   if (lowest)
     clutter_container_lower_child (CLUTTER_CONTAINER(layer),
         CLUTTER_ACTOR (marker), CLUTTER_ACTOR (lowest));
-
-  g_list_free (markers);
 }
 
 static void
 marker_position_notify (GObject *gobject,
-    GParamSpec *pspec,
+    G_GNUC_UNUSED GParamSpec *pspec,
     gpointer user_data)
 {
   reorder_marker (CLUTTER_GROUP (user_data), CHAMPLAIN_BASE_MARKER (gobject));
@@ -161,7 +161,7 @@ marker_position_notify (GObject *gobject,
 static void
 layer_add_cb (ClutterGroup *layer,
     ClutterActor *actor,
-    gpointer data)
+    G_GNUC_UNUSED gpointer data)
 {
   ChamplainBaseMarker *marker = CHAMPLAIN_BASE_MARKER (actor);
   reorder_marker (layer, marker);
@@ -173,7 +173,7 @@ layer_add_cb (ClutterGroup *layer,
 static void
 layer_remove_cb (ClutterGroup *layer,
     ClutterActor *actor,
-    gpointer data)
+    G_GNUC_UNUSED gpointer data)
 {
   g_signal_handlers_disconnect_by_func (G_OBJECT (actor),
       G_CALLBACK (marker_position_notify), layer);
@@ -182,6 +182,8 @@ layer_remove_cb (ClutterGroup *layer,
 /**
  * champlain_layer_new:
  *
+ * Creates a new instance of #ChamplainLayer.
+ *
  * Returns: a new #ChamplainLayer ready to be used as a #ClutterContainer for the markers.
  *
  * Since: 0.2.2
@@ -208,7 +210,7 @@ champlain_layer_add_marker (ChamplainLayer *layer,
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
   g_return_if_fail (CHAMPLAIN_IS_BASE_MARKER (marker));
 
-  clutter_container_add (CLUTTER_CONTAINER (layer), CLUTTER_ACTOR (marker), NULL);
+  clutter_container_add_actor (CLUTTER_CONTAINER (layer), CLUTTER_ACTOR (marker));
 }
 
 /**
@@ -227,7 +229,7 @@ champlain_layer_remove_marker (ChamplainLayer *layer,
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
   g_return_if_fail (CHAMPLAIN_IS_BASE_MARKER (marker));
 
-  clutter_container_remove (CLUTTER_CONTAINER (layer), CLUTTER_ACTOR (marker), NULL);
+  clutter_container_remove_actor (CLUTTER_CONTAINER (layer), CLUTTER_ACTOR (marker));
 }
 
 /**
@@ -273,21 +275,18 @@ champlain_layer_hide (ChamplainLayer *layer)
 void
 champlain_layer_animate_in_all_markers (ChamplainLayer *layer)
 {
-  GList *children, *child;
+  guint i;
   guint delay = 0;
 
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
 
-  children = clutter_container_get_children (CLUTTER_CONTAINER (layer));
-
-  for (child = children; child != NULL; child = g_list_next (child))
+  for (i = 0; i < clutter_group_get_n_children (CLUTTER_GROUP (layer)); i++)
     {
-      champlain_base_marker_animate_in_with_delay (CHAMPLAIN_BASE_MARKER (child->data),
-          delay);
+      ChamplainBaseMarker *marker = CHAMPLAIN_BASE_MARKER (clutter_group_get_nth_child (CLUTTER_GROUP (layer), i));
+
+      champlain_base_marker_animate_in_with_delay (marker, delay);
       delay += 50;
     }
-
-  g_list_free (children);
 }
 
 /**
@@ -301,21 +300,18 @@ champlain_layer_animate_in_all_markers (ChamplainLayer *layer)
 void
 champlain_layer_animate_out_all_markers (ChamplainLayer *layer)
 {
-  GList *children, *child;
+  guint i;
   guint delay = 0;
 
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
 
-  children = clutter_container_get_children (CLUTTER_CONTAINER (layer));
-
-  for (child = children; child != NULL; child = g_list_next (child))
+  for (i = 0; i < clutter_group_get_n_children (CLUTTER_GROUP (layer)); i++)
     {
-      champlain_base_marker_animate_out_with_delay (CHAMPLAIN_BASE_MARKER (child->data),
-          delay);
+      ChamplainBaseMarker *marker = CHAMPLAIN_BASE_MARKER (clutter_group_get_nth_child (CLUTTER_GROUP (layer), i));
+
+      champlain_base_marker_animate_out_with_delay (marker, delay);
       delay += 50;
     }
-
-  g_list_free (children);
 }
 
 /**
@@ -329,18 +325,16 @@ champlain_layer_animate_out_all_markers (ChamplainLayer *layer)
 void
 champlain_layer_show_all_markers (ChamplainLayer *layer)
 {
-  GList *children, *child;
+  guint i;
 
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
 
-  children = clutter_container_get_children (CLUTTER_CONTAINER (layer));
-
-  for (child = children; child != NULL; child = g_list_next (child))
+  for (i = 0; i < clutter_group_get_n_children (CLUTTER_GROUP (layer)); i++)
     {
-      clutter_actor_show (CLUTTER_ACTOR (child->data));
-    }
+      ClutterActor *marker = CLUTTER_ACTOR (clutter_group_get_nth_child (CLUTTER_GROUP (layer), i));
 
-  g_list_free (children);
+      clutter_actor_show (marker);
+    }
 }
 
 /**
@@ -354,16 +348,14 @@ champlain_layer_show_all_markers (ChamplainLayer *layer)
 void
 champlain_layer_hide_all_markers (ChamplainLayer *layer)
 {
-  GList *children, *child;
+  guint i;
 
   g_return_if_fail (CHAMPLAIN_IS_LAYER (layer));
 
-  children = clutter_container_get_children (CLUTTER_CONTAINER (layer));
-
-  for (child = children; child != NULL; child = g_list_next (child))
+  for (i = 0; i < clutter_group_get_n_children (CLUTTER_GROUP (layer)); i++)
     {
-      clutter_actor_hide (CLUTTER_ACTOR (child->data));
-    }
+      ClutterActor *marker = CLUTTER_ACTOR (clutter_group_get_nth_child (CLUTTER_GROUP (layer), i));
 
-  g_list_free (children);
+      clutter_actor_hide (marker);
+    }
 }
