@@ -22,7 +22,10 @@
 #include <glib.h>
 #include <clutter/clutter.h>
 
-typedef struct _Map Map;
+/*
+ * WARNING - NEVER put class private declarations here - add accessor methods
+ * to the classes instead. Object encapsulation should be sacred.
+ */
 
 typedef struct
 {
@@ -31,26 +34,6 @@ typedef struct
   gfloat z;
 } ChamplainFloatPoint;
 
-struct _ChamplainBaseMarkerPrivate
-{
-  gdouble lon;
-  gdouble lat;
-  gboolean highlighted;
-};
-
-struct _ChamplainPolygonPrivate {
-  GList *points;
-  gboolean closed_path;
-  ClutterColor *stroke_color;
-  gboolean fill;
-  ClutterColor *fill_color;
-  gboolean stroke;
-  gdouble stroke_width;
-  ClutterActor *actor;
-  gboolean visible;
-  gboolean mark_points;
-};
-
 typedef struct
 {
   gfloat x;
@@ -59,4 +42,12 @@ typedef struct
   gint height;
 } ChamplainRectangle;
 
+#define CHAMPLAIN_PARAM_READABLE     \
+        (G_PARAM_READABLE |     \
+         G_PARAM_STATIC_NICK | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB)
+
+#define CHAMPLAIN_PARAM_READWRITE    \
+        (G_PARAM_READABLE | G_PARAM_WRITABLE | \
+         G_PARAM_STATIC_NICK | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB)
+
 #endif
