@@ -31,7 +31,7 @@
 
 #include "champlain-selection-layer.h"
 
-#include "champlain-defines.h"
+#include "champlain-private.h"
 #include "champlain-base-marker.h"
 #include "champlain-enum-types.h"
 
@@ -43,12 +43,21 @@ G_DEFINE_TYPE (ChamplainSelectionLayer, champlain_selection_layer, CHAMPLAIN_TYP
 #define GET_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHAMPLAIN_TYPE_SELECTION_LAYER, ChamplainSelectionLayerPrivate))
 
+enum
+{
+  /* normal signals */
+  CHANGED,
+  LAST_SIGNAL
+};
+
 enum
 {
   PROP_0,
   PROP_SELECTION_MODE
 };
 
+static guint signals[LAST_SIGNAL] = { 0, };
+
 struct _ChamplainSelectionLayerPrivate {
   ChamplainSelectionMode mode;
   GList *selection;
@@ -91,6 +100,18 @@ champlain_selection_layer_set_property (GObject *object,
     }
 }
 
+static void
+champlain_selection_layer_dispose (GObject *object)
+{
+  G_OBJECT_CLASS (champlain_selection_layer_parent_class)->dispose (object);
+}
+
+static void
+champlain_selection_layer_finalize (GObject *object)
+{
+  G_OBJECT_CLASS (champlain_selection_layer_parent_class)->finalize (object);
+}
+
 static void
 champlain_selection_layer_class_init (ChamplainSelectionLayerClass *klass)
 {
@@ -98,11 +119,13 @@ champlain_selection_layer_class_init (ChamplainSelectionLayerClass *klass)
 
   g_type_class_add_private (klass, sizeof (ChamplainSelectionLayerPrivate));
 
+  object_class->finalize = champlain_selection_layer_finalize;
+  object_class->dispose = champlain_selection_layer_dispose;
   object_class->get_property = champlain_selection_layer_get_property;
   object_class->set_property = champlain_selection_layer_set_property;
 
   /**
-  * ChamplainView:selection-mode:
+  * ChamplainSelectionLayer:selection-mode:
   *
   * Determines the type of selection that will be performed.
   *
@@ -116,16 +139,31 @@ champlain_selection_layer_class_init (ChamplainSelectionLayerClass *klass)
            CHAMPLAIN_TYPE_SELECTION_MODE,
            CHAMPLAIN_SELECTION_SINGLE,
            CHAMPLAIN_PARAM_READWRITE));
+
+  /**
+  * ChamplainSelectionLayer::changed
+  *
+  * The changed signal is emitted when the selected marker(s) change.
+  *
+  * Since: 0.4.1
+  */
+  signals[CHANGED] =
+      g_signal_new ("changed", G_OBJECT_CLASS_TYPE (object_class),
+          G_SIGNAL_RUN_LAST, 0, NULL, NULL,
+          g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 }
 
 static void
 marker_select (ChamplainSelectionLayer *layer,
     ChamplainBaseMarker *marker)
 {
+
   /* Add selection */
   g_object_ref (marker);
   g_object_set (marker, "highlighted", TRUE, NULL);
   layer->priv->selection = g_list_prepend (layer->priv->selection, marker);
+
+  g_signal_emit_by_name (layer, "changed", NULL);
 }
 
 static void
@@ -197,7 +235,7 @@ marker_clicked_cb (ClutterActor *actor,
 static void
 layer_add_cb (ClutterGroup *layer,
     ClutterActor *actor,
-    gpointer data)
+    G_GNUC_UNUSED gpointer data)
 {
   ChamplainBaseMarker *marker = CHAMPLAIN_BASE_MARKER (actor);
 
@@ -210,7 +248,7 @@ layer_add_cb (ClutterGroup *layer,
 static void
 layer_remove_cb (ClutterGroup *layer,
     ClutterActor *actor,
-    gpointer data)
+    G_GNUC_UNUSED gpointer data)
 {
   g_signal_handlers_disconnect_by_func (G_OBJECT (actor),
       G_CALLBACK (marker_clicked_cb), layer);
@@ -232,6 +270,8 @@ champlain_selection_layer_init (ChamplainSelectionLayer *self)
 /**
  * champlain_selection_layer_new:
  *
+ * Creates an instance of #ChamplainSelectionLayer.
+ *
  * Returns: a new #ChamplainSelectionLayer ready to be used as a #ClutterContainer for the markers.
  *
  * Since: 0.4
@@ -243,7 +283,8 @@ champlain_selection_layer_new ()
 }
 
 /**
- * champlain_selection_get_selected:
+ * champlain_selection_layer_get_selected:
+ * @layer: a #ChamplainSelectionLayer
  *
  * This function will return NULL if in CHAMPLAIN_SELETION_MULTIPLE.
  *
@@ -264,7 +305,10 @@ champlain_selection_layer_get_selected (ChamplainSelectionLayer *layer)
 }
 
 /**
- * champlain_selection_get_selected_markers:
+ * champlain_selection_layer_get_selected_markers:
+ * @layer: a #ChamplainSelectionLayer
+ *
+ * Gets the list of selected markers.
  *
  * Returns: the list of selected #ChamplainBaseMarker or NULL if none is selected.
  * You shouldn't free that list.
@@ -279,6 +323,9 @@ champlain_selection_layer_get_selected_markers (ChamplainSelectionLayer *layer)
 
 /**
  * champlain_selection_layer_count_selected_markers:
+ * @layer: a #ChamplainSelectionLayer
+ *
+ * Gets the number of selected markers.
  *
  * Returns: the number of selected #ChamplainBaseMarker
  *
@@ -287,6 +334,8 @@ champlain_selection_layer_get_selected_markers (ChamplainSelectionLayer *layer)
 guint
 champlain_selection_layer_count_selected_markers (ChamplainSelectionLayer *layer)
 {
+  g_return_val_if_fail (CHAMPLAIN_IS_SELECTION_LAYER (layer), 0);
+
   return g_list_length (layer->priv->selection);
 }
 
@@ -303,6 +352,9 @@ void
 champlain_selection_layer_select (ChamplainSelectionLayer *layer,
     ChamplainBaseMarker *marker)
 {
+  g_return_if_fail (CHAMPLAIN_IS_SELECTION_LAYER (layer));
+  g_return_if_fail (CHAMPLAIN_IS_BASE_MARKER (marker));
+
   api_select (layer, marker);
 }
 
@@ -317,6 +369,8 @@ champlain_selection_layer_select (ChamplainSelectionLayer *layer,
 void
 champlain_selection_layer_unselect_all (ChamplainSelectionLayer *layer)
 {
+  g_return_if_fail (CHAMPLAIN_IS_SELECTION_LAYER (layer));
+
   GList *selection = layer->priv->selection;
 
   DEBUG ("Deselect all");
@@ -327,6 +381,8 @@ champlain_selection_layer_unselect_all (ChamplainSelectionLayer *layer)
       selection = g_list_delete_link (selection, selection);
     }
   layer->priv->selection = selection;
+
+  g_signal_emit_by_name (layer, "changed", NULL);
 }
 
 /**
@@ -341,6 +397,8 @@ champlain_selection_layer_unselect_all (ChamplainSelectionLayer *layer)
 void
 champlain_selection_layer_select_all (ChamplainSelectionLayer *layer)
 {
+  g_return_if_fail (CHAMPLAIN_IS_SELECTION_LAYER (layer));
+
   gint n_children = 0;
   gint i = 0;
 
@@ -376,6 +434,9 @@ void
 champlain_selection_layer_unselect (ChamplainSelectionLayer *layer,
     ChamplainBaseMarker *marker)
 {
+  g_return_if_fail (CHAMPLAIN_IS_SELECTION_LAYER (layer));
+  g_return_if_fail (CHAMPLAIN_IS_BASE_MARKER (marker));
+
   GList *selection;
 
   DEBUG ("Deselect %p", marker);
@@ -385,6 +446,8 @@ champlain_selection_layer_unselect (ChamplainSelectionLayer *layer,
       g_object_set (selection->data, "highlighted", FALSE, NULL);
       g_object_unref (selection->data);
       layer->priv->selection = g_list_delete_link (layer->priv->selection, selection);
+
+      g_signal_emit_by_name (layer, "changed", NULL);
     }
 }
 
@@ -393,6 +456,8 @@ champlain_selection_layer_unselect (ChamplainSelectionLayer *layer,
  * @layer: a #ChamplainSelectionLayer
  * @marker: a #ChamplainBaseMarker
  *
+ * Checks whether the marker is selected.
+ *
  * Returns: whether the marker is selected or not.
  *
  * Since: 0.4
@@ -401,6 +466,9 @@ gboolean
 champlain_selection_layer_marker_is_selected (ChamplainSelectionLayer *layer,
     ChamplainBaseMarker *marker)
 {
+  g_return_val_if_fail (CHAMPLAIN_IS_SELECTION_LAYER (layer), FALSE);
+  g_return_val_if_fail (CHAMPLAIN_IS_BASE_MARKER (marker), FALSE);
+
   GList *selection;
 
   selection = g_list_find (layer->priv->selection, marker);
@@ -441,6 +509,8 @@ champlain_selection_layer_set_selection_mode (ChamplainSelectionLayer *layer,
  * champlain_selection_layer_get_selection_mode:
  * @layer: a #ChamplainSelectionLayer
  *
+ * Gets the selection mode of the layer.
+ *
  * Returns: the selection mode of the layer.
  *
  * Since: 0.4
